@@ -65,7 +65,9 @@ int Fl_screen_h(void);
 
 int Fl_screen_w(void);
 
-void Fl_paste(Fl_Widget *, int src);
+void Fl_paste_text(Fl_Widget *, int src);
+
+void Fl_paste_image(Fl_Widget *widget, int src);
 
 void Fl_set_scheme(const char *scheme);
 
@@ -187,6 +189,8 @@ void Fl_get_system_colors(void);
 
 int Fl_handle(int, void *);
 
+int Fl_handle_(int, void *);
+
 void Fl_add_idle(void (*)(void *), void *);
 
 int Fl_has_idle(void (*)(void *), void *);
@@ -225,6 +229,14 @@ int Fl_box_dh(int boxtype);
 
 int Fl_mac_os_version(void);
 
+void *Fl_event_clipboard(void);
+
+const char *Fl_event_clipboard_type(void);
+
+int Fl_clipboard_contains(const char *type);
+
+void Fl_event_dispatch(int (*cb)(int event, void *));
+
 #ifdef __cplusplus
 }
 #endif
